[![DOI](https://zenodo.org/badge/440811484.svg)](https://zenodo.org/badge/latestdoi/440811484) [![Documentation Status](https://readthedocs.org/projects/anticpy/badge/?version=latest)](https://anticpy.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/antiCPy.svg)](https://badge.fury.io/py/antiCPy)

antiCPy
=======

The antiCPy package provides an easy applicable toolbox to estimate the drift slope 
<img src="https://render.githubusercontent.com/render/math?math=\hat{\zeta}">
of a Langevin
equation as an early warning signal and extrapolate an early warning signal trend to find the probable transition
horizon based on the current data information. The package aims to provide simple applicable methods and guarantee high
flexibility and also access to the derived interim results.

Citing antiCPy
==============

Please cite the publication 

Heßler et al 2021 New J. Phys. https://doi.org/10.1088/1367-2630/ac46d4

in your publications for which you used **antiCPy**.

Documentation
=============

You can find the [documentation on read the docs](https://anticpy.readthedocs.io/en/latest/).

Install
=======

The package can be installed via

```
pip install antiCPy
```

Related publications
====================
Up to now the package is accompanied by the preprint
paper [Bayesian on-line anticipation of critical transitions](https://arxiv.org/abs/2108.05179).
